==> http-executor-commons-1.16.2-sources.jar: org/dmfs/httpessentials/executors/common/DelegatingHttpRequestExecutor.java <==
/*
 * Copyright 2017 dmfs GmbH
 *
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.dmfs.httpessentials.executors.common;

import org.dmfs.httpessentials.client.HttpRequest;
import org.dmfs.httpessentials.client.HttpRequestExecutor;
import org.dmfs.httpessentials.exceptions.ProtocolError;
import org.dmfs.httpessentials.exceptions.ProtocolException;
import org.dmfs.httpessentials.exceptions.RedirectionException;
import org.dmfs.httpessentials.exceptions.UnexpectedStatusException;

import java.io.IOException;
import java.net.URI;


/**
 * An {@link HttpRequestExecutor} to which delegates all calls to another {@link HttpRequestExecutor}.
 * <p>
 * This is a workaround for the lack of native support of the delegator pattern in Java.
 *
 * @author Marten Gajda
 */
public abstract class DelegatingHttpRequestExecutor implements HttpRequestExecutor
{
    private final HttpRequestExecutor mDelegate;


    protected DelegatingHttpRequestExecutor(HttpRequestExecutor delegate)
    {
        mDelegate = delegate;
    }


    @Override
    public final <T> T execute(URI uri, HttpRequest<T> request) throws IOException, ProtocolError, ProtocolException, RedirectionException, UnexpectedStatusException
    {
        return mDelegate.execute(uri, request);
    }
}

==> http-executor-commons-1.22.1-sources.jar: org/dmfs/httpessentials/executors/common/DelegatingHttpRequestExecutor.java <==
/*
 * Copyright 2017 dmfs GmbH
 *
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.dmfs.httpessentials.executors.common;

import org.dmfs.httpessentials.client.HttpRequest;
import org.dmfs.httpessentials.client.HttpRequestExecutor;
import org.dmfs.httpessentials.exceptions.ProtocolError;
import org.dmfs.httpessentials.exceptions.ProtocolException;

import java.io.IOException;
import java.net.URI;


/**
 * An {@link HttpRequestExecutor} to which delegates all calls to another {@link HttpRequestExecutor}.
 * <p>
 * This is a workaround for the lack of native support of the delegator pattern in Java.
 *
 * @author Marten Gajda
 */
public abstract class DelegatingHttpRequestExecutor implements HttpRequestExecutor
{
    private final HttpRequestExecutor mDelegate;


    protected DelegatingHttpRequestExecutor(HttpRequestExecutor delegate)
    {
        mDelegate = delegate;
    }


    @Override
    public final <T> T execute(URI uri, HttpRequest<T> request) throws IOException, ProtocolError, ProtocolException
    {
        return mDelegate.execute(uri, request);
    }
}
